@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,21 +21,19 @@ use futures::Future;
 #[cfg(feature = "authorization")]
 use crate::admin::rest_api::CIRCUIT_READ_PERMISSION;
 use crate::admin::store::AdminServiceStore;
-use crate::protocol;
 use crate::rest_api::{
     actix_web_1::{Method, ProtocolVersionRangeGuard, Resource},
-    ErrorResponse,
+    ErrorResponse, SPLINTER_PROTOCOL_VERSION,
 };
 
 use super::super::error::CircuitFetchError;
 use super::super::resources;
 
+const ADMIN_FETCH_CIRCUIT_MIN: u32 = 1;
+
 pub fn make_fetch_circuit_resource(store: Box<dyn AdminServiceStore>) -> Resource {
     let resource = Resource::build("/admin/circuits/{circuit_id}").add_request_guard(
-        ProtocolVersionRangeGuard::new(
-            protocol::ADMIN_FETCH_CIRCUIT_MIN,
-            protocol::ADMIN_PROTOCOL_VERSION,
-        ),
+        ProtocolVersionRangeGuard::new(ADMIN_FETCH_CIRCUIT_MIN, SPLINTER_PROTOCOL_VERSION),
     );
     #[cfg(feature = "authorization")]
     {
@@ -68,7 +66,7 @@ fn fetch_circuit(
                 "Unable to get SplinterProtocolVersion".to_string(),
             )),
         },
-        None => Ok(format!("{}", protocol::ADMIN_PROTOCOL_VERSION)),
+        None => Ok(format!("{}", SPLINTER_PROTOCOL_VERSION)),
     };
 
     Box::new(
@@ -155,7 +153,7 @@ mod tests {
         .expect("Failed to parse URL");
         let req = Client::new()
             .get(url)
-            .header("SplinterProtocolVersion", protocol::ADMIN_PROTOCOL_VERSION);
+            .header("SplinterProtocolVersion", SPLINTER_PROTOCOL_VERSION);
         let resp = req.send().expect("Failed to perform request");
 
         assert_eq!(resp.status(), StatusCode::OK);
@@ -224,7 +222,7 @@ mod tests {
         .expect("Failed to parse URL");
         let req = Client::new()
             .get(url)
-            .header("SplinterProtocolVersion", protocol::ADMIN_PROTOCOL_VERSION);
+            .header("SplinterProtocolVersion", SPLINTER_PROTOCOL_VERSION);
         let resp = req.send().expect("Failed to perform request");
 
         assert_eq!(resp.status(), StatusCode::NOT_FOUND);
