@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,16 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#[cfg(feature = "rest-api-actix")]
 mod actix_web_1;
 
-#[cfg(all(feature = "authorization", feature = "rest-api-actix"))]
+#[cfg(feature = "authorization")]
 use crate::rest_api::auth::authorization::Permission;
 
-#[cfg(feature = "rest-api-actix")]
 pub use actix_web_1::BiomeProfileRestResourceProvider;
 
-#[cfg(all(feature = "authorization", feature = "rest-api-actix"))]
+#[cfg(feature = "authorization")]
 const BIOME_PROFILE_READ_PERMISSION: Permission = Permission::Check {
     permission_id: "biome.profile.read",
     permission_display_name: "Biome profile read",
