@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ extern crate log;
 #[macro_use]
 extern crate serde_derive;
 #[macro_use]
-#[cfg(feature = "rest-api")]
+#[cfg(feature = "rest-api-actix-web-1")]
 extern crate serde_json;
 #[macro_use]
 #[cfg(feature = "diesel")]
@@ -36,6 +36,7 @@ extern crate metrics;
 #[macro_use]
 pub mod tap;
 
+#[doc(hidden)]
 #[macro_export]
 macro_rules! rwlock_read_unwrap {
     ($lock:expr) => {
@@ -46,6 +47,7 @@ macro_rules! rwlock_read_unwrap {
     };
 }
 
+#[doc(hidden)]
 #[macro_export]
 macro_rules! rwlock_write_unwrap {
     ($lock:expr) => {
@@ -56,6 +58,7 @@ macro_rules! rwlock_write_unwrap {
     };
 }
 
+#[doc(hidden)]
 #[macro_export]
 macro_rules! mutex_lock_unwrap {
     ($lock:expr) => {
@@ -71,7 +74,7 @@ pub mod admin;
 mod base62;
 #[cfg(feature = "biome")]
 pub mod biome;
-pub mod channel;
+pub(crate) mod channel;
 pub mod circuit;
 mod collections;
 pub mod consensus;
@@ -98,12 +101,12 @@ pub mod registry;
 pub mod rest_api;
 pub mod service;
 pub mod sets;
-#[cfg(feature = "store-factory")]
+#[cfg(feature = "store")]
 pub mod store;
 pub mod threading;
 pub mod transport;
 
-#[cfg(feature = "rest-api")]
+#[cfg(feature = "rest-api-actix-web-1")]
 pub use actix_web;
-#[cfg(feature = "rest-api")]
+#[cfg(feature = "rest-api-actix-web-1")]
 pub use futures;
