@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -23,7 +23,6 @@ use std::convert::TryFrom;
 use crate::actix_web::{error::BlockingError, web, Error, HttpRequest, HttpResponse};
 use crate::error::InvalidStateError;
 use crate::futures::{future::IntoFuture, stream::Stream, Future};
-use crate::protocol;
 use crate::registry::rest_api::error::RegistryRestApiError;
 #[cfg(feature = "authorization")]
 use crate::registry::rest_api::{REGISTRY_READ_PERMISSION, REGISTRY_WRITE_PERMISSION};
@@ -34,18 +33,18 @@ use crate::registry::{
 use crate::rest_api::{
     actix_web_1::{Method, ProtocolVersionRangeGuard, Resource},
     paging::{get_response_paging_info, DEFAULT_LIMIT, DEFAULT_OFFSET},
-    percent_encode_filter_query, ErrorResponse,
+    percent_encode_filter_query, ErrorResponse, SPLINTER_PROTOCOL_VERSION,
 };
 
+const REGISTRY_LIST_NODES_MIN: u32 = 1;
+
 type Filter = HashMap<String, (String, String)>;
 
 pub fn make_nodes_resource(registry: Box<dyn RwRegistry>) -> Resource {
     let registry1 = registry.clone();
-    let resource =
-        Resource::build("/registry/nodes").add_request_guard(ProtocolVersionRangeGuard::new(
-            protocol::REGISTRY_LIST_NODES_MIN,
-            protocol::REGISTRY_PROTOCOL_VERSION,
-        ));
+    let resource = Resource::build("/registry/nodes").add_request_guard(
+        ProtocolVersionRangeGuard::new(REGISTRY_LIST_NODES_MIN, SPLINTER_PROTOCOL_VERSION),
+    );
     #[cfg(feature = "authorization")]
     {
         resource
@@ -301,10 +300,7 @@ mod tests {
             .expect("Failed to parse URL");
         let resp = Client::new()
             .get(url)
-            .header(
-                "SplinterProtocolVersion",
-                protocol::REGISTRY_PROTOCOL_VERSION,
-            )
+            .header("SplinterProtocolVersion", SPLINTER_PROTOCOL_VERSION)
             .send()
             .expect("Failed to perform request");
 
@@ -362,10 +358,7 @@ mod tests {
         .expect("Failed to parse URL");
         let resp = Client::new()
             .get(url)
-            .header(
-                "SplinterProtocolVersion",
-                protocol::REGISTRY_PROTOCOL_VERSION,
-            )
+            .header("SplinterProtocolVersion", SPLINTER_PROTOCOL_VERSION)
             .send()
             .expect("Failed to perform request");
 
@@ -412,10 +405,7 @@ mod tests {
         .expect("Failed to parse URL");
         let resp = Client::new()
             .get(url)
-            .header(
-                "SplinterProtocolVersion",
-                protocol::REGISTRY_PROTOCOL_VERSION,
-            )
+            .header("SplinterProtocolVersion", SPLINTER_PROTOCOL_VERSION)
             .send()
             .expect("Failed to perform request");
 
@@ -438,10 +428,7 @@ mod tests {
             .expect("Failed to parse URL");
         let resp = Client::new()
             .post(url)
-            .header(
-                "SplinterProtocolVersion",
-                protocol::REGISTRY_PROTOCOL_VERSION,
-            )
+            .header("SplinterProtocolVersion", SPLINTER_PROTOCOL_VERSION)
             .send()
             .expect("Failed to perform request");
 
@@ -452,10 +439,7 @@ mod tests {
             .expect("Failed to parse URL");
         let resp = Client::new()
             .post(url)
-            .header(
-                "SplinterProtocolVersion",
-                protocol::REGISTRY_PROTOCOL_VERSION,
-            )
+            .header("SplinterProtocolVersion", SPLINTER_PROTOCOL_VERSION)
             .json(&get_new_node_1())
             .send()
             .expect("Failed to perform request");
